@@ -20,4 +20,6 @@ def main():
 
 
 if __name__ == "__main__":
-    main()
+    ethane = main()
+    import pdb
+    pdb.set_trace()
