@@ -3,7 +3,7 @@ from __future__ import division
 from numpy import pi
 
 from mbuild.compound import Compound
-from mbuild.examples.pmpc_brush_layer.surface import Surface
+from mbuild.examples.alkane_monolayer.surface import Surface
 from mbuild.examples.pmpc_brush_layer.brush import Brush
 from mbuild.tools.mask import apply_mask, random_mask_2d
 from mbuild.tools.tiled_compound import TiledCompound
@@ -29,6 +29,8 @@ class BrushLayer(Compound):
 def main():
     mask = random_mask_2d(20)
     brush_layer = BrushLayer(chain_length=20, alpha=pi/4, mask=mask, tile_x=3, tile_y=2)
+    brush_layer.visualize()
+
     brush_layer = brush_layer.to_trajectory()
     brush_layer.topology.find_forcefield_terms()
 
